SpiEventSource

Struct SpiEventSource 

pub struct SpiEventSource<'d> { /* private fields */ }
Implementations

Source

impl<'d> SpiEventSource<'d>

pub fn polling(interval: Duration) -> Result<Self, TryFromIntError>

Instead of getting informed by an interrupt pin about updates/changes from the emac, the MCU polls the emac periodically for updates.

In most cases, Self::interrupt should be used as it is more efficient. But this source makes e.g. sense if the interrupt pin of the emac is not connected to the MCU.

pub fn interrupt(pin: impl InputPin + 'd) -> Self

Get status updates/changes from the emac by way of an interrupt pin.

If the interrupt pin is not connected, see Self::polling for an alternative.